@@ -1,7 +1,7 @@
 package HTML::Menu::TreeView::GER;
 use strict;
 use warnings;
-$HTML::Menu::TreeView::GER::VERSION = '1.02';
+$HTML::Menu::TreeView::GER::VERSION = '1.03';
 
 =head1 NAME
 
@@ -53,7 +53,7 @@ HTML::Menu::TreeView
 
                text => 'Folder',
 
-               folderclass => 'folderMan', # Nur für Crystal Styles.
+               folderclass => 'folderMan', # Nur fr Crystal Styles.
 
                subtree => [
 
@@ -96,7 +96,7 @@ HTML::Menu::TreeView
 
 =head3 Funktions- Sets
 
-Hier die liste der möglichen Import Sets
+Hier die liste der mglichen Import Sets
 
 :all
 
@@ -128,13 +128,13 @@ HTML::Menu::TreeView ist ein Module um ein HTML TreeView zu erstellen.
 
 Deutsche Umlaute wurden falsch dargestellt.
 
-Einige Ergänzungen in der Deutschen Dokumentation.
+Einige Ergnzungen in der Deutschen Dokumentation.
 
 =head1 Public
 
 =head2 new
 
-     Bei der Objektorientierten Schnittstelle kann man die Array Referenz direkt an new übergeben
+     Bei der Objektorientierten Schnittstelle kann man die Array Referenz direkt an new bergeben
 
      ms $TreeView = new HTML::Menu::TreeView(\@tree, optional style);
 
@@ -144,63 +144,63 @@ Einige Ergänzungen in der Deutschen Dokumentation.
 
 =head2 css
 
-Gibt den benötigten Stylesheet(css) zurück, der In die Seite eingebunden werden muss.
+Gibt den bentigten Stylesheet(css) zurck, der In die Seite eingebunden werden muss.
 
-Mann kann den Document Root setzen wenn man ein Argument übergibt.
+Mann kann den Document Root setzen wenn man ein Argument bergibt.
 
      css('/document/root/');
 
-Man kann den benötigten Stylesheet natürlich per Hand einbinden:
+Man kann den bentigten Stylesheet natrlich per Hand einbinden:
 
      <link href="/style/Crystal/16/html-menu-treeview/Crystal.css" rel="stylesheet" type="text/css">
 
 =head2 documentRoot
 
-Setzt den Document Root im Scalar Context, gibt Ihn in void Context zurück.
+Setzt den Document Root im Scalar Context, gibt Ihn in void Context zurck.
 
 default: Diese Variable wird durch make gesetzt.
 
 =head2 jscript
 
-Gibt den benötigten Javascript zurück, der In die Seite eingebunden werden muss.
+Gibt den bentigten Javascript zurck, der In die Seite eingebunden werden muss.
 
-Mann kann den Document Root setzen wenn man ein Argument übergibt.
+Mann kann den Document Root setzen wenn man ein Argument bergibt.
 
-Man kann den benötigten Javascript natürlich per Hand einbinden:
+Man kann den bentigten Javascript natrlich per Hand einbinden:
 
      <script language="JavaScript" type="text/javascript" src="/style/treeview.js"></script>
 
 =head2 preload
 
-Gibt den benötigten javascript zurück um Bilder per Javascript in Vorhinein zu laden.
+Gibt den bentigten javascript zurck um Bilder per Javascript in Vorhinein zu laden.
 
-Mann kann den document root setzen wenn man ein Argument übergibt.
+Mann kann den document root setzen wenn man ein Argument bergibt.
 
-Man kann den benötigten javascript natürlich auch per Hand einbinden.
+Man kann den bentigten javascript natrlich auch per Hand einbinden.
 
-Für eine Größe:
+Fr eine Gre:
 
      <script language="JavaScript" type="text/javascript" src="/style/Crystal/16/html-menu-treeview/preload.js"></script>
 
-Oder für alle Größen:
+Oder fr alle Gren:
 
      <script language="JavaScript" type="text/javascript" src="/style/Crystal/preload.js"></script>
 
 =head2 size
 
-Verschiedene Größen sind nur für den Crystal Style verfügbar.
+Verschiedene Gren sind nur fr den Crystal Style verfgbar.
 
-Setzt die Größe im Scalar Context, gibt Sie in void Context zurück.
+Setzt die Gre im Scalar Context, gibt Sie in void Context zurck.
 
-16,32,48,64 und 128 sind mögliche Werte.
+16,32,48,64 und 128 sind mgliche Werte.
 
 =head2 Style
 
-Setzt den Style im Scalar Context, gibt Ihn in void Context zurück.
+Setzt den Style im Scalar Context, gibt Ihn in void Context zurck.
 
      Style('simple');
 
-simple = Redmond mäßiger style.
+simple = Redmond miger style.
 
 Crystal = Kde Crystal style (default).
 
@@ -208,7 +208,7 @@ Crystal = Kde Crystal style (default).
 
      Tree(\@tree,optional $style);
 
-Gibt den HTML teil des Treeviews ohne Javascript und Css zurück.
+Gibt den HTML teil des Treeviews ohne Javascript und Css zurck.
 
 =head2 clasic
 
@@ -220,7 +220,7 @@ klassische Knoten Dekoration ausschalten
 
      clasic(0);
 
-gibt den Status in void Context zurück.
+gibt den Status in void Context zurck.
 
      $status = clasic();
 
@@ -230,11 +230,11 @@ Anzahl der Spalten setzen.
 
      columns(3);
 
-Gibt die Anzahl in void Context zurück.
+Gibt die Anzahl in void Context zurck.
 
      $anzahl = columns();
 
-Oder man kann die Titel für die Spalten Setzen
+Oder man kann die Titel fr die Spalten Setzen
 
      columns("Name","Column 1","Column 2","Column 3");
 
@@ -285,9 +285,9 @@ default: ./TreeViewDump.pl
 
 =head2 help
 
-Die Hilfe für die Link Attribute
+Die Hilfe fr die Link Attribute
 
-gibt eine Referenz auf ein hash zurück (void Context),
+gibt eine Referenz auf ein hash zurck (void Context),
 
      my $hashref =  help();
 
@@ -301,7 +301,7 @@ oder eine Hilfe Nachricht.
 
      print help('href'),$/;
 
-(Nur auf Englisch verfügbar)
+(Nur auf Englisch verfgbar)
 
 =head3 reservierte Attribute:
 
@@ -327,7 +327,7 @@ Name der Klasse des Elements.
 
 =item coords
 
-Für Image maps.
+Fr Image maps.
 
 =item dir
 
@@ -355,15 +355,15 @@ Wenn mit der Maus auf das Element geklickt wird.
 
 =item onfocus
 
-Element wird ausgewählt.
+Element wird ausgewhlt.
 
 =item onkeydown
 
-Wenn eine taste gedrückt wird.
+Wenn eine taste gedrckt wird.
 
 =item onkeypress
 
-Wenn eine taste gedrückt und wieder losgelassen wird.
+Wenn eine taste gedrckt und wieder losgelassen wird.
 
 =item onkeyup
 
@@ -371,7 +371,7 @@ Wenn die taste wieder losgelassen wird.
 
 =item onmousedown
 
-Wenn eine Maustaste gedrückt wird.
+Wenn eine Maustaste gedrckt wird.
 
 =item onmousemove
 
@@ -379,11 +379,11 @@ Maus wird bewegt.
 
 =item onmouseout
 
-Maus verlässt den link.
+Maus verlsst den link.
 
 =item onmouseover
 
-Maus über den link
+Maus ber den link
 
 =item onmouseup
 
@@ -399,7 +399,7 @@ Dieses Attribut gibt die Zeichenkodierung der durch den Link bezeichneten Ressou
 
 =item shape
 
-Für image maps.
+Fr image maps.
 
 =item style
 
@@ -411,13 +411,13 @@ Position in der tab Reihenfolge.
 
 =item target
 
-Mit dem Attribut target im einleitenden <a>-Tag können Sie ein Zielfenster für den Verweis festlegen. Der im Wert zugewiesene Name muss mit einem Buchstaben (A-Z, a-z) beginnen, außer in den folgenden
+Mit dem Attribut target im einleitenden <a>-Tag knnen Sie ein Zielfenster fr den Verweis festlegen. Der im Wert zugewiesene Name muss mit einem Buchstaben (A-Z, a-z) beginnen, auer in den folgenden
 
-Ausnahmen, die durch einen führenden Unterstrich gekennzeichnet sind:
+Ausnahmen, die durch einen fhrenden Unterstrich gekennzeichnet sind:
 
-_blank, um den Verweis in einem neuen Fenster zu öffnen,
+_blank, um den Verweis in einem neuen Fenster zu ffnen,
 
- _self, um den Verweis im aktuellen Fenster zu öffnen,
+ _self, um den Verweis im aktuellen Fenster zu ffnen,
 
  _parent, um bei verschachtelten Framesets das aktuelle Frameset zu sprengen,
 
@@ -438,7 +438,7 @@ Die id des links. Wird gesetzt.
 
 =item addition
 
-Zusätzlicher text hinter dem link.
+Zustzlicher text hinter dem link.
 
 =item subtree
 
@@ -456,9 +456,9 @@ Bild Name, muss im /style/mimetypes Verzeichnis liegen
 
 =item folderclass :
 
-Nur für Crystal styles
+Nur fr Crystal styles
 
-Mögliche Werte:
+Mgliche Werte:
 
 folderMan, folderVideo,folderCrystal,
 
@@ -472,7 +472,7 @@ folderTar,folderYellow ,folderGray,
 
 folderGreen und folderRed
 
-Auf  http://treeview.lindnerei.de/cgi-bin/crystal.pl gibt es eine komplette liste möglicher werte.
+Auf  http://treeview.lindnerei.de/cgi-bin/crystal.pl gibt es eine komplette liste mglicher werte.
 
 =item columns
 
@@ -480,7 +480,7 @@ Ein Array mit den Spalten.
 
 =item empty.
 
-Auf wahr setzen wenn man einen geschlossenes Verzeichnis haben möchte.
+Auf wahr setzen wenn man einen geschlossenes Verzeichnis haben mchte.
 
 =back
 
@@ -526,11 +526,11 @@ Wird innerhalb von initTree zum sortieren benutzt wenn Verzeichnisse zuerst ange
 
 =head2 getSelf
 
-Dieses Module benutzt ein Lincoln loader mäßiges Klassen System.
+Dieses Module benutzt ein Lincoln loader miges Klassen System.
 
-Wenn der erste übergebene Parameter von ein HTML::Menu::TreeView Objekt ist (oo syntax). werden einfach die übergebenen Parameter zurück gegeben.
+Wenn der erste bergebene Parameter von ein HTML::Menu::TreeView Objekt ist (oo syntax). werden einfach die bergebenen Parameter zurck gegeben.
 
-Ansonsten (fo syntax)  wird ein neues HTML::Menu::TreeView Objekt erzeugt und als erster wert gefolgt von den übergeben Parametern zurückgegeben.
+Ansonsten (fo syntax)  wird ein neues HTML::Menu::TreeView Objekt erzeugt und als erster wert gefolgt von den bergeben Parametern zurckgegeben.
 
 =head2 appendFolder
 
@@ -582,17 +582,17 @@ LGPL
 
 Copyright (C) 2008  Dirk Lindner
 
-Diese Bibliothek ist freie Software. Sie dürfen sie unter den Bedingungen
-der GNU Lesser General Public License, wie von der Free Software Foundation veröffentlicht,
-weiterverteilen und/oder modifizieren; entweder gemäß Version 2.1 der Lizenz oder (nach Ihrer
-Option) jeder späteren Version. Diese Bibliothek wird in der Hoffnung weiterverbreitet,
-daß sie nützlich sein wird, jedoch OHNE IRGENDEINE GARANTIE,
-auch ohne die implizierte Garantie der MARKTREIFE oder der VERWENDBARKEIT FÜR EINEN BESTIMMTEN ZWECK.
-Mehr Details finden Sie in der GNU Lesser General Public License. 
+Diese Bibliothek ist freie Software. Sie drfen sie unter den Bedingungen
+der GNU Lesser General Public License, wie von der Free Software Foundation verffentlicht,
+weiterverteilen und/oder modifizieren; entweder gem Version 2.1 der Lizenz oder (nach Ihrer
+Option) jeder spteren Version. Diese Bibliothek wird in der Hoffnung weiterverbreitet,
+da sie ntzlich sein wird, jedoch OHNE IRGENDEINE GARANTIE,
+auch ohne die implizierte Garantie der MARKTREIFE oder der VERWENDBARKEIT FR EINEN BESTIMMTEN ZWECK.
+Mehr Details finden Sie in der GNU Lesser General Public License.
 Sie sollten eine Kopie der GNU Lesser General Public License zusammen mit dieser Bibliothek erhalten haben.
 falls nicht,
 schreiben Sie an die Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA.
 
 =cut
 
-1;
\ No newline at end of file
+1;
